You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by dl...@apache.org on 2005/10/19 10:46:08 UTC

svn commit: r326482 [2/2] - /incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jlThread.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jlThread.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jlThread.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jlThread.c Wed Oct 19 01:44:42 2005
@@ -3,18 +3,21 @@
  *
  * @brief Native implementation of @c @b java.lang.Thread
  *
- * @todo  Perform intelligent check on input parameter
- *        @b objhash range for all functions.
+ * @todo  HARMONY-6-jvm-jlThread.c-1 Perform intelligent check on
+ *        input parameter @b objhash range for all functions.
  *
- * @todo  In real life, the @b objhashthis values and @b clsidxthis
- *        values will be valid or these functions could not be
- *        invoked since these data types are @e mandatory for
- *        referencing them.  This probably means that the parameter
- *        valididty checking could probably be relaxed.
+ * @todo  HARMONY-6-jvm-jlThread.c-2 In real life, the @b objhashthis
+ *        values and @b clsidxthis values will be valid or these
+ *        functions could not be invoked since these data types
+ *        are @e mandatory for referencing them.  This probably
+ *        means that the parameter valididty checking could probably
+ *        be relaxed.
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -38,6 +41,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -45,7 +49,9 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(jlThread, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(jlThread, c,
+"$URL$",
+"$Id$");
 
 
 #include "jvmcfg.h"
@@ -94,15 +100,17 @@
  *
  *
  * @note These @c @b java.lang.Thread methods are unusual in that
- * they does not require a @c @b jobject (in parlance of this
- * implementation, a @link #jvm_object_hash jvm_object_hash@endlink)
- * to run because they are declared as @c @b static methods.  As
- * implemented here, the usual @b objhashthis parameter is therefore
- * replaced by * @b clsidxthis.  The thread context is located in
- * @link #CURRENT_THREAD CURRENT_THREAD@endlink.
+ *       they does not require a @c @b jobject (in parlance of this
+ *       implementation, a
+ *       @link #jvm_object_hash jvm_object_hash@endlink)
+ *       to run because they are declared as @c @b static methods.  As
+ *       implemented here, the usual @b objhashthis parameter is
+ *       therefore replaced by @b clsidxthis.  The thread context is
+ *       located in @link #CURRENT_THREAD CURRENT_THREAD@endlink.
  *
  *
- * @todo Make sure thread interruption logic below here is working.
+ * @todo HARMONY-6-jvm-jlThread.c-3 Make sure thread interruption
+ *       logic below here is working.
  *
  */
 
@@ -117,6 +125,8 @@
 jvoid jlThread_sleep(jvm_class_index clsidxthis,
                      jlong           sleeptime_milliseconds)
 {
+    ARCH_FUNCTION_NAME(jlThread_sleep);
+
     /* Current thread always assumed valid */
     jvm_thread_index thridx = CURRENT_THREAD;
 
@@ -141,6 +151,8 @@
                            jlong           sleeptime_milliseconds,
                            jint            sleeptime_nanoseconds)
 {
+    ARCH_FUNCTION_NAME(jlThread_sleep_nanos);
+
     /* Do nothing with @b sleeptime_nanoseconds */
 
     jlThread_sleep(clsidxthis, sleeptime_milliseconds);
@@ -177,14 +189,17 @@
  * @param  sleeptime_nanoseconds   Number of nanoseconds to wait on join
  *                                 in addition to the milliseconds.
  *
+ *
  * @returns @link #jvoid jvoid@endlink
  *
+ *
  * @throws JVMCLASS_JAVA_LANG_INTERRUPTEDEXCEPTION
  *         @link #JVMCLASS_JAVA_LANG_INTERRUPTEDEXCEPTION
            if another thread had interrupted this thread@endlink.
  *
  *
- * @todo Make sure thread interruption logic below here is working.
+ * @todo HARMONY-6-jvm-jlThread.c-4 Make sure thread interruption
+ *       logic below here is working.
  *
  */
 
@@ -197,6 +212,8 @@
 
 jvoid jlThread_join4ever(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_join4ever);
+
     /* Current thread always assumed valid */
     jvm_thread_index thridxthis = CURRENT_THREAD;
 
@@ -220,6 +237,8 @@
 jvoid jlThread_jointimed(jvm_object_hash objhashthis,
                          jlong           sleeptime)
 {
+    ARCH_FUNCTION_NAME(jlThread_jointimed);
+
     /* Current thread always assumed valid */
     jvm_thread_index thridxthis = CURRENT_THREAD;
 
@@ -247,6 +266,8 @@
                                jlong           sleeptime,
                                jint            sleeptime_nanoseconds)
 {
+    ARCH_FUNCTION_NAME(jlThread_jointimed_nanos);
+
     /* Do nothing with @b sleeptime_nanoseconds */
 
     jlThread_jointimed(objhashthis, sleeptime);
@@ -265,12 +286,13 @@
  * as the first parameter.
  *
  * @note These @c @b java.lang.Thread methods are unusual in that
- * they does not require a @c @b jobject (in parlance of this
- * implementation, a @link #jvm_object_hash jvm_object_hash@endlink)
- * to run because they are declared as @c @b static methods.  As
- * implemented here, the usual @b objhashthis parameter is therefore
- * replaced by * @b clsidxthis.  The thread context is located in
- * @link #CURRENT_THREAD CURRENT_THREAD@endlink.
+ *       they does not require a @c @b jobject (in parlance of this
+ *       implementation, a
+ *       @link #jvm_object_hash jvm_object_hash@endlink)
+ *       to run because they are declared as @c @b static methods.  As
+ *       implemented here, the usual @b objhashthis parameter is
+ *       therefore replaced by @b clsidxthis.  The thread context is
+ *       located in @link #CURRENT_THREAD CURRENT_THREAD@endlink.
  *
  */
 
@@ -294,6 +316,8 @@
 
 jvm_object_hash jlThread_currentThread(jvm_class_index clsidxthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_currentThread);
+
     /* Current thread always assumed valid */
     return(THREAD(CURRENT_THREAD).thread_objhash);
 
@@ -315,6 +339,8 @@
  */
 jboolean jlThread_yield(jvm_class_index clsidxthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_yield);
+
     /* Current thread always assumed valid */
     jvm_thread_index thridx = CURRENT_THREAD;
 
@@ -337,9 +363,9 @@
  * Status is @b CLEARED by this method after testing it.
  *
  * @note <b>This is a static method and has no need of a
- * @c @b this object hash.  Therefore, the first
- * parameter is @e not an object hash, but the first
- * application parameter itself.</b>
+ *       @c @b this object hash.  Therefore, the first
+ *       parameter is @e not an object hash, but the first
+ *       application parameter itself.</b>
  *
  *
  * @param  clsidxthis  Class table index of the class of
@@ -348,12 +374,14 @@
  *
  *
  * @returns @link #jtrue jtrue@endlink if thread has been interrupted,
- * else @link #jfalse jfalse@endlink.
+ *          else @link #jfalse jfalse@endlink.
  *
  */
 
 jboolean jlThread_interrupted(jvm_class_index clsidxthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_interrupted);
+
     /* Current thread always assumed valid */
     jvm_thread_index thridx = CURRENT_THREAD;
 
@@ -383,7 +411,7 @@
  *
  *
  * @returns @link #jtrue jtrue@endlink if this thread holds the
- * object's monitor lock, else @link #jfalse jfalse@endlink.
+ *          object's monitor lock, else @link #jfalse jfalse@endlink.
  *
  * @throws JVMCLASS_JAVA_LANG_NULLPOINTEREXCEPTION
  *         @link #JVMCLASS_JAVA_LANG_NULLPOINTEREXCEPTION
@@ -394,6 +422,8 @@
 jboolean jlThread_holdsLock(jvm_class_index clsidxthis,
                             jvm_object_hash objhashLOCK)
 {
+    ARCH_FUNCTION_NAME(jlThread_holdsLock);
+
     if (jvm_object_hash_null == objhashLOCK)
     {
         /*
@@ -448,7 +478,7 @@
  *
  *
  * @returns @link #jtrue jtrue@endlink if thread could be modified, else
- * throw @b SecurityException.
+ *          throw @b SecurityException.
  *
  *
  * @throws JVMCLASS_JAVA_LANG_SECURITYEXCEPTION
@@ -459,6 +489,8 @@
 
 jboolean jlThread_interrupt(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_interrupt);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -492,12 +524,14 @@
  *
  *
  * @returns @link #jtrue jtrue@endlink if thread has been interrupted,
- * else @link #jfalse jfalse@endlink.
+ *          else @link #jfalse jfalse@endlink.
  *
  */
 
 jboolean jlThread_isInterrupted(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_isInterrupted);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -528,10 +562,11 @@
  *
  *
  * @returns @link #jtrue jtrue@endlink if thread is in use and
- * not @b NEW and neither @b COMPLETE (transient) nor @b DEAD,
- * else @link #jfalse jfalse@endlink.
+ *          not @b NEW and neither @b COMPLETE (transient) nor @b DEAD,
+ *          else @link #jfalse jfalse@endlink.
  *
- * @todo  CAVEAT:  Should this thread eventually get reallocated as
+ * @todo  HARMONY-6-jvm-jlThread.c-5 CAVEAT:  Should this thread
+ *        eventually get reallocated as
  *        @link #rjvm.thread_new_last pjvm->thread_new_last@endlink
  *        wraps around after @link #JVMCFG_MAX_THREADS
           JVMCFG_MAX_THREADS@endlink more new threads, this function
@@ -543,6 +578,8 @@
 
 jboolean jlThread_isAlive(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_isAlive);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -577,7 +614,7 @@
  *
  *
  * @returns @link #jtrue jtrue@endlink if thread could be started,
- * else @link #jfalse jfalse@endlink.
+ *          else @link #jfalse jfalse@endlink.
  *
  * @throws JVMCLASS_JAVA_LANG_INTERRUPTEDEXCEPTION
  *         @link #JVMCLASS_JAVA_LANG_INTERRUPTEDEXCEPTION
@@ -587,6 +624,8 @@
 
 jboolean jlThread_start(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_start);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -626,6 +665,8 @@
 
 jint jlThread_countStackFrames(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_countStackFrames);
+
     jint rc = 0;
 
     if ((rfalse == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) ||
@@ -676,6 +717,7 @@
  *          @link #jtrue jtrue@endlink,
  *          else @link #jfalse jfalse@endlink.
  *
+ *
  * @throws JVMCLASS_JAVA_LANG_ILLEGALARGUMENTEXCEPTION
  *         @link #JVMCLASS_JAVA_LANG_ILLEGALARGUMENTEXCEPTION
            if the requested thread priorty is out of range@endlink.
@@ -684,13 +726,16 @@
  *         @link #JVMCLASS_JAVA_LANG_SECURITYEXCEPTION
            if this thread cannot have its priority modified@endlink.
  *
- * @todo Add logic to detect @b SecurityException.
+ * @todo HARMONY-6-jvm-jlThread.c-6 Add logic to detect
+ *       @b SecurityException.
  *
  */
 
 jboolean jlThread_setPriority(jvm_object_hash objhashthis,
                               jint             priority)
 {
+    ARCH_FUNCTION_NAME(jlThread_setPriority);
+
     if ((THREAD_PRIORITY_MIN > priority) ||
         (THREAD_PRIORITY_MAX < priority))
     {
@@ -746,6 +791,8 @@
 
 jint jlThread_getPriority(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_getPriority);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -775,8 +822,8 @@
  * @c @b java.lang.Thread.destroy(Runnable) ,
  * but will initially be done here.
  *
- * @todo  Should this be implemented? Some JDK's probably don't
- *        implement it any more.
+ * @todo  HARMONY-6-jvm-jlThread.c-7 Should this be implemented?
+ *        Some JDK's probably don't implement it any more.
  *
  *
  * @param  objhashthis  Object table hash of @c @b this object.
@@ -789,6 +836,8 @@
 
 jboolean jlThread_destroy(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_destroy);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -817,8 +866,8 @@
  *
  * This method will @e always give permission in this JVM.
  *
- * @todo  A smart java.lang.SecurityManager will take
- *        care of this matter.
+ * @todo  HARMONY-6-jvm-jlThread.c-8 A smart java.lang.SecurityManager
+ *        will take care of this matter.
  *
  *
  * @param  objhashthis  Object table hash of @c @b this object.
@@ -831,12 +880,15 @@
  *         @link #JVMCLASS_JAVA_LANG_SECURITYEXCEPTION
        if current thread is not permitted to modify this thread@endlink.
  *
- * @todo Add logic to detect @b SecurityException beyond passing in
- * an invalid @b objhashthis.
+ * @todo HARMONY-6-jvm-jlThread.c-9 Add logic to detect
+ *       @b SecurityException beyond passing in
+ *       an invalid @b objhashthis.
  *
  */
 jboolean jlThread_checkAccess(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_checkAccess);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -862,9 +914,10 @@
  * @brief Native implementation
  * of <code>java.lang.Thread.setDaemon()<code>
  *
- * @todo  See notes elsewhere about implementation of the ISDAEMON bit.
- *        This concept must be implemented in the JVM structures so as
- *        to know when to quit (no non-daemon threads running, that is,
+ * @todo  HARMONY-6-jvm-jlThread.c-10 See notes elsewhere about
+ *        implementation of the ISDAEMON bit.  This concept must
+ *        be implemented in the JVM structures so as to know
+ *        when to quit (no non-daemon threads running, that is,
  *        no user threads running).  Currently, it is a status bit in
  *        the @link rthread#status rthread.status@endlink structure
  *        named
@@ -887,7 +940,7 @@
  *
  *
  * @returns @link #jtrue jtrue@endlink if could make the change,
- * else throw @b SecurityException.
+ *          else throw @b SecurityException.
  *
  *
  * @throws JVMCLASS_JAVA_LANG_ILLEGALTHREADSTATEEXCEPTION
@@ -900,17 +953,21 @@
            if current thread cannot change this thread@endlink.
  *
  *
- * @todo Review jvm_init() code for setting up threads before there
- *       is a @c @b setjmp(3) handler for @c @b setDaemon() exceptions.
- *
- * @todo Add logic to detect @b SecurityException beyond passing in
- * an invalid @b objhashthis.
+ * @todo HARMONY-6-jvm-jlThread.c-11 Review jvm_init() code for
+ *       setting up threads before there is a @c @b setjmp(3) handler
+ *       for @c @b setDaemon() exceptions.
+ *
+ * @todo HARMONY-6-jvm-jlThread.c-12 Add logic to detect
+ *       @b SecurityException beyond passing in an invalid
+ *       @b objhashthis.
  *
  */
 
 jvoid jlThread_setDaemon(jvm_object_hash objhashthis,
                         jboolean        isdaemon)
 {
+    ARCH_FUNCTION_NAME(jlThread_setDaemon);
+
     if ((rfalse == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) ||
         (rfalse == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -954,7 +1011,8 @@
  * @brief Native implementation
  * of @c @b java.lang.Thread.isDaemon()
  *
- * @todo  See notes elsewhere about implementation of the ISDAEMON bit.
+ * @todo  HARMONY-6-jvm-jlThread.c-13 See notes elsewhere about
+ *        implementation of the @b ISDAEMON bit.
  *
  *
  * @param  objhashthis  Object table hash of @c @b this object.
@@ -967,6 +1025,8 @@
 
 jboolean jlThread_isDaemon(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_isDaemon);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -989,13 +1049,15 @@
  * @brief Native implementation
  * of @c @b java.lang.Thread.setName()
  *
- * @todo  Needs work to convert java.lang.String into
- *        (rthread).name (written @e long before @b String code).
+ * @todo  HARMONY-6-jvm-jlThread.c-14 Needs work to convert
+ *        java.lang.String into (rthread).name (written
+ *        @e long before @b String code).
  *
  *
  * @param  objhashthis  Object table hash of @c @b this object.
  *
- *         name    Null-terminated string containing new thread name
+ *         name         Null-terminated string containing new
+ *                      thread name
  *
  *
  * @returns @link #jvoid jvoid@endlink
@@ -1004,6 +1066,8 @@
 jvoid jlThread_setName(jvm_object_hash  objhashthis,
                        rchar           *newname)
 {
+    ARCH_FUNCTION_NAME(jlThread_setName);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -1024,8 +1088,9 @@
  * @brief Native implementation
  * of @c @b java.lang.Thread.getName()
  *
- * @todo  Needs work to convert java.lang.String into
- *        (rthread).name (written @e long before @b String code).
+ * @todo  HARMONY-6-jvm-jlThread.c-15 Needs work to convert
+ *        java.lang.String into (rthread).name (written
+ *        @e long before @b String code).
  *
  *
  * @param  objhashthis  Object table hash of @c @b this object.
@@ -1036,6 +1101,8 @@
  */
 jvm_object_hash jlThread_getName(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_getName);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -1070,20 +1137,23 @@
  *
  *
  * @returns @link #jtrue jtrue@endlink if thread could be modified,
- * else throw @b SecurityException
+ *          else throw @b SecurityException
  *
  *
  * @throws JVMCLASS_JAVA_LANG_SECURITYEXCEPTION
  *         @link #JVMCLASS_JAVA_LANG_SECURITYEXCEPTION
            if current thread cannot change this thread@endlink.
  *
- * @todo Add logic to detect @b SecurityException beyond passing in
- * an invalid @b objhashthis.
+ * @todo HARMONY-6-jvm-jlThread.c-16 Add logic to detect
+ *       @b SecurityException beyond passing in
+ *       an invalid @b objhashthis.
  *
  */
 
 jvoid jlThread_stop(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_stop);
+
     if ((rfalse == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) ||
         (rfalse == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -1151,20 +1221,23 @@
  *
  *
  * @returns @link #jtrue jtrue@endlink if thread could be modified,
- * else throw @b SecurityException.
+ *          else throw @b SecurityException.
  *
  *
  * @throws JVMCLASS_JAVA_LANG_SECURITYEXCEPTION
  *         @link #JVMCLASS_JAVA_LANG_SECURITYEXCEPTION
            if could not suspend thread@endlink.
  *
- * @todo Add logic to detect @b SecurityException beyond passing in
- * an invalid @b objhashthis.
+ * @todo HARMONY-6-jvm-jlThread.c-17 Add logic to
+ *       detect @b SecurityException beyond passing in
+ *       an invalid @b objhashthis.
  *
  */
 
 jvoid jlThread_suspend(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_suspend);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))
@@ -1215,20 +1288,23 @@
  *
  *
  * @returns @link #jtrue jtrue@endlink if thread could be modified,
- * else throw @b SecurityException.
+ *          else throw @b SecurityException.
  *
  *
  * @throws JVMCLASS_JAVA_LANG_SECURITYEXCEPTION
  *         @link #JVMCLASS_JAVA_LANG_SECURITYEXCEPTION
            if could not suspend thread@endlink.
  *
- * @todo Add logic to detect @b SecurityException beyond passing in
- * an invalid @b objhashthis.
+ * @todo HARMONY-6-jvm-jlThread.c-18 Add logic to
+ *       detect @b SecurityException beyond passing in
+ *       an invalid @b objhashthis.
  *
  */
 
 jvoid jlThread_resume(jvm_object_hash objhashthis)
 {
+    ARCH_FUNCTION_NAME(jlThread_resume);
+
     if ((rtrue == VERIFY_OBJECT_THREAD_LINKAGE(objhashthis)) &&
         (rtrue == VERIFY_THREAD_LINKAGE(
                       OBJECT_THREAD_LINKAGE(objhashthis)->thridx)))

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jrtypes.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jrtypes.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jrtypes.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jrtypes.c Wed Oct 19 01:44:42 2005
@@ -9,7 +9,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -33,6 +35,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -40,7 +43,9 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(jrtypes, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(jrtypes, c,
+"$URL$",
+"$Id$");
 
 
 /*!

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jrtypes.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jrtypes.h?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jrtypes.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jrtypes.h Wed Oct 19 01:44:42 2005
@@ -53,21 +53,23 @@
  *       found in its @c @b some.java.class.with.native.methods
  *       directory.  For example, the Java class
  *       @c @b java.lang.Object has its Java source file stored
- *    in @link jni/src/harmony/generic/0.0/src/java/lang/Object.java
-   jni/src/vendor/product/version/src/java/lang/Object.java@endlink,
- *        with its native support found in the 'C' source file
- *      @link jni/src/harmony/generic/0.0/src/java_lang_Object.c
-  jni/src/vendor/product/version/src/java_lang_Object.c@endlink.
- *        The JNI header used to access this native
- *        @c @b java.lang.Object code is found in the related
- *        @b include directory as
- *      @link jni/src/harmony/generic/0.0/include/java_lang_Object.h
-  jni/src/vendor/product/version/include/java_lang_Object.h@endlink.
+ *       in @link jni/src/harmony/generic/0.0/src/java/lang/Object.java
+       jni/src/vendor/product/version/src/java/lang/Object.java@endlink,
+ *       with its native support found in the 'C' source file
+ *       @link jni/src/harmony/generic/0.0/src/java_lang_Object.c
+         jni/src/vendor/product/version/src/java_lang_Object.c@endlink.
+ *       The JNI header used to access this native
+ *       @c @b java.lang.Object code is found in the related
+ *       @b include directory as
+ *       @link jni/src/harmony/generic/0.0/include/java_lang_Object.h
+      jni/src/vendor/product/version/include/java_lang_Object.h@endlink.
  *
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -91,13 +93,16 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
  *
  */
 
-ARCH_COPYRIGHT_APACHE(jrtypes, h, "$URL$ $Id$");
+ARCH_HEADER_COPYRIGHT_APACHE(jrtypes, h,
+"$URL$",
+"$Id$");
 
 
 /*!
@@ -340,8 +345,8 @@
 
 /*!
  * @internal Destroy any pre-existing version (or even conflicting
- * versions) of several common symbols, then define them explicitly
- * for this compile environment.
+ *           versions) of several common symbols, then define them
+ *           explicitly for this compile environment.
  */
 #ifdef NULL
 #undef NULL
@@ -371,19 +376,20 @@
 
 /*@{ */ /* Begin grouped definitions */
 
-#define TRUE  DO_NOT_USE_TRUE  /**< Please use either @link #rtrue
+#define TRUE  PLEASE_DO_NOT_USE_TRUE /**< Please use either @link #rtrue
                                     rtrue@endlink for real machine
                                     @c @b TRUE cases or @link #jtrue
                                     jtrue@endlink for Java virtual
                                     machine @c @b TRUE cases */ 
 
-#define FALSE DO_NOT_USE_FALSE /**< Please use either @link #rfalse
-                                    rfalse@endlink for real machine
-                                    @c @b FALSE cases or @link #jfalse
-                                    jfalse@endlink for Java virtual
-                                    machine @c @b FALSE cases */ 
+#define FALSE PLEASE_DO_NOT_USE_FALSE /**< Please use either
+                                     @link #rfalse rfalse@endlink for
+                                    real machine @c @b FALSE cases or
+                                    @link #jfalse jfalse@endlink for
+                                    Java virtual machine @c @b FALSE
+                                    cases */ 
 
-#define NULL  DO_NOT_USE_NULL  /**< Please use @link #rnull
+#define NULL  PLEASE_DO_NOT_USE_NULL  /**< Please use @link #rnull
                                     rnull@endlink for real machine
                                     @c @b NULL cases or @link #jnull
                                     jnull@endlink for Java virtual

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvalue.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvalue.h?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvalue.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvalue.h Wed Oct 19 01:44:42 2005
@@ -12,7 +12,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -36,6 +38,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -43,7 +46,9 @@
  */
 
 
-ARCH_COPYRIGHT_APACHE(jvalue, h, "$URL$ $Id$");
+ARCH_HEADER_COPYRIGHT_APACHE(jvalue, h,
+"$URL$",
+"$Id$");
 
 /*!
  * @brief Java aggregate type references for object definitions.

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmcfg.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmcfg.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmcfg.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmcfg.c Wed Oct 19 01:44:42 2005
@@ -6,7 +6,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -30,6 +32,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -37,7 +40,9 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(jvmcfg, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(jvmcfg, c,
+"$URL$",
+"$Id$");
 
 
 #define I_AM_JVMCFG_C /* Permit xxx_NULL_xxx definition constants */

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmclass.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmclass.h?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmclass.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmclass.h Wed Oct 19 01:44:42 2005
@@ -10,7 +10,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -34,13 +36,16 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
  *
  */
 
-ARCH_COPYRIGHT_APACHE(jvmclass, h, "$URL$ $Id$");
+ARCH_HEADER_COPYRIGHT_APACHE(jvmclass, h,
+"$URL$",
+"$Id$");
 
 
 /*! Package name for internal Java language classes */

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmutil.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmutil.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/linkage.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/linkage.c Wed Oct 19 01:44:42 2005
@@ -14,7 +14,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -38,6 +40,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -45,7 +48,9 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(linkage, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(linkage, c,
+"$URL$",
+"$Id$");
 
 #include "jvmcfg.h"
 #include "cfmacros.h"
@@ -91,6 +96,8 @@
 rboolean linkage_resolve_class(jvm_class_index clsidx,
                                rboolean        find_registerNatives)
 {
+    ARCH_FUNCTION_NAME(linkage_resolve_class);
+
     if (jvm_class_index_null == clsidx)
     {
         /*!
@@ -124,7 +131,7 @@
     rboolean class_fully_linked = rtrue;
 
     /*
-     * Scan through constant_pool, resolving any missing items
+     * Scan through @c @b constant_pool, resolving any missing items
      * that might now be available.
      */
 
@@ -314,8 +321,9 @@
                                           PTR_THIS_CP_Utf8(pfldesc_dup);
 
                         /*!
-                         * @todo What needs to happen when base type
-                         *       is BASETYPE_ARRAY or BASETYPE_ERROR
+                         * @todo HARMONY-6-jvm-linkage.c-1 What needs
+                         *       to happen when base type is
+                         *       BASETYPE_ARRAY or BASETYPE_ERROR
                          *       or BASETYPE_VOID?
                          */
                         pcpd_Fieldref
@@ -528,8 +536,9 @@
                             atridxFIND = jvm_attribute_index_native;
 
                             /*!
-                             * @todo Should this instance permit
-                             *       use of @b find_registerNatives
+                             * @todo HARMONY-6-jvm-linkage.c-2 Should
+                             *       this instance permit use
+                             *       of @b find_registerNatives
                              *       since interaces are not a part
                              *       of the JVM startup, just a few
                              *       foundational classes?  Should
@@ -626,7 +635,7 @@
             default:
                 GENERIC_FAILURE1_VALUE(rtrue,
                                        DMLNORM,
-                                       "linkage_resolve_class",
+                                       arch_function_name,
                                        "Invalid CP tag %d",
                                        CP_TAG(pcfs, cpidx),
                                        rfalse,
@@ -666,6 +675,8 @@
 
 rboolean linkage_unresolve_class(jvm_class_index clsidx)
 {
+    ARCH_FUNCTION_NAME(linkage_unresolve_class);
+
     if (jvm_class_index_null == clsidx)
     {
         /*
@@ -872,7 +883,7 @@
             default:
                 GENERIC_FAILURE1_VALUE(rtrue,
                                        DMLNORM,
-                                       "linkage_rmresolve_class",
+                                       arch_function_name,
                                        "Invalid CP tag %d",
                                        CP_TAG(pcfs, cpidx),
                                        rfalse,

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/linkage.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/linkage.h?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/linkage.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/linkage.h Wed Oct 19 01:44:42 2005
@@ -29,7 +29,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -53,13 +55,16 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
  *
  */
 
-ARCH_COPYRIGHT_APACHE(linkage, h, "$URL$ $Id$");
+ARCH_HEADER_COPYRIGHT_APACHE(linkage, h,
+"$URL$",
+"$Id$");
 
 
 /*!
@@ -88,6 +93,7 @@
  * @param  objhash    Object hash of object for which to locate its
  *                    class table entry.
  *
+ *
  * @returns (jvm_table_linkage *) to object table class linkage entry
  *
  */
@@ -109,7 +115,8 @@
  *
  *
  * @returns @link #rtrue rtrue@endlink if this thread index indicates
- * a valid thread table slot, otherwise @link #rfalse rfalse@endlink.
+ *          a valid thread table slot, otherwise
+ *          @link #rfalse rfalse@endlink.
  *
  */
 #define VERIFY_THREAD_LINKAGE(thridx)                            \
@@ -169,8 +176,9 @@
  *                               class object.
  *
  * @note  This macro will return @link #rnull rnull@endlink if the
- * object in this slot is not a <b><code>java.lang.Thread</code></b>
- * object and one which indexes a valid thread.
+ *        object in this slot is not a
+ *        <b><code>java.lang.Thread</code></b> object and one
+ *        which indexes a valid thread.
  *
  */
 #define OBJECT_THREAD_LINKAGE(objhash)                                 \
@@ -192,8 +200,8 @@
  *
  *
  * @returns @link #rtrue rtrue@endlink if this object hash indicates
- * a valid thread linkage and a thread table slot, otherwise
- * @link #rfalse rfalse@endlink.
+ *          a valid thread linkage and a thread table slot, otherwise
+ *          @link #rfalse rfalse@endlink.
  *
  */
 #define VERIFY_OBJECT_THREAD_LINKAGE(objhash)   \

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/native.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/native.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/native.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/native.c Wed Oct 19 01:44:42 2005
@@ -318,7 +318,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -342,6 +344,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -349,7 +352,9 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(native, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(native, c,
+"$URL$",
+"$Id$");
 
 #include "jvmcfg.h"
 #include "classfile.h"
@@ -519,8 +524,9 @@
  *
  * @returns @link #rvoid rvoid@endlink
  *
- * @todo Perform value set conversion here for native methods
- *       and elsewhere for virtual methods.
+ *
+ * @todo HARMONY-6-jvm-native.c-1 Perform value set conversion here
+ *       for native methods and elsewhere for virtual methods.
  *
  */
 #define POP_JFLOAT(thridx) \
@@ -556,8 +562,9 @@
  *
  * @returns @link #rvoid rvoid@endlink
  *
- * @todo Perform value set conversion here for native methods
- *       and elsewhere for virtual methods.
+ *
+ * @todo HARMONY-6-jvm-native.c-2 Perform value set conversion here
+ *       for native methods and elsewhere for virtual methods.
  *
  */
 #define POP_JDOUBLE(thridx) \
@@ -599,6 +606,8 @@
     rvoid native_run_local_return_jvoid(jvm_native_method_ordinal nmord,
                                         jvm_thread_index         thridx)
 {
+    ARCH_FUNCTION_NAME(native_run_local_return_jvoid);
+
     POP_SCRATCHPAD_JVM;
     POP_SCRATCHPAD_JINT;
     POP_SCRATCHPAD_JLONG;
@@ -701,6 +710,8 @@
     native_run_local_return_jobject(jvm_native_method_ordinal nmord,
                                     jvm_thread_index         thridx)
 {
+    ARCH_FUNCTION_NAME(native_run_local_return_jobject);
+
     jvm_object_hash rc;
 
     POP_SCRATCHPAD_JVM;
@@ -749,6 +760,8 @@
     jint native_run_local_return_jint(jvm_native_method_ordinal nmord,
                                       jvm_thread_index         thridx)
 {
+    ARCH_FUNCTION_NAME(native_run_local_return_jint);
+
     jint rc;
 
     POP_SCRATCHPAD_JVM;
@@ -888,6 +901,8 @@
     native_run_local_return_jfloat(jvm_native_method_ordinal nmord,
                                    jvm_thread_index         thridx)
 {
+    ARCH_FUNCTION_NAME(native_run_local_return_jfloat);
+
     jfloat rc;
 
     /* POP_SCRATCHPAD_JVM; */
@@ -922,6 +937,8 @@
     jlong native_run_local_return_jlong(jvm_native_method_ordinal nmord,
                                         jvm_thread_index         thridx)
 {
+    ARCH_FUNCTION_NAME(native_run_local_return_jlong);
+
     jlong rc;
     jint rcms, rcls;
 
@@ -961,6 +978,8 @@
     native_run_local_return_jdouble(jvm_native_method_ordinal nmord,
                                     jvm_thread_index         thridx)
 {
+    ARCH_FUNCTION_NAME(native_run_local_return_jdouble);
+
     jdouble rc;
     jint rcms, rcls;
 
@@ -999,12 +1018,13 @@
  * methods.
  *
  * @internal  Although this function is invoked from
- * @link #native_locate_local_method()
-          native_locate_local_method()@endlink, the real purpose
- * is fulfilled at compile time by verifying that there is a
- * completely unique set of ordinals across all classes.  Invoking
- * it at run time adds to this integrity by verifying that a
- * native method invocation is using an ordinal that actually exists.
+ *            @link #native_locate_local_method()
+              native_locate_local_method()@endlink, the real purpose
+ *            is fulfilled at compile time by verifying that there is a
+ *            completely unique set of ordinals across all classes.
+ *            Invoking it at run time adds to this integrity by
+ *            verifying that a native method invocation is using an
+ *            ordinal that actually exists.
  *
  *
  * @param nmord   Ordinal number definition of local native method.
@@ -1023,6 +1043,8 @@
 static rvoid native_verify_ordinal_definition(
                                         jvm_native_method_ordinal nmord)
 {
+    ARCH_FUNCTION_NAME(native_verify_ordinal_definition);
+
     switch(nmord)
     {
         /*
@@ -1145,13 +1167,13 @@
    NATIVE_TABLE_JLxxxxx_ORDINALS@endlink.  This suite is entered
  * here for processing by the local native method logic.
  *
- * @see jvm/include/jlClass.h
+ * @see @link jvm/include/jlClass.h jvm/include/jlClass.h@endlink
  *
- * @see jvm/include/jlObject.h
+ * @see @link jvm/include/jlObject.h jvm/include/jlObject.h@endlink
  *
- * @see jvm/include/jlString.h
+ * @see @link jvm/include/jlString.h jvm/include/jlString.h@endlink
  *
- * @see jvm/include/jlThread.h
+ * @see @link jvm/include/jlThread.h jvm/include/jlThread.h@endlink
  *
  */
 native_local_method_map native_local_method_list[NLML_MAX_CLASSES] =
@@ -1189,16 +1211,16 @@
  *
  * @param pcfs        ClassFile pointer of a class referencing a
  *                    native method, local or otherwise.  The following
- *                    constant_pool indices are all relative to this
- *                    ClassFile.
+ *                    @c @b constant_pool indices are all relative to
+ *                    this ClassFile.
  *
- * @param clsnameidx  constant_pool index in @b pcfs of class name to
- *                    locate in class table.
+ * @param clsnameidx  @c @b constant_pool index in @b pcfs of class name
+ *                    to locate in class table.
  *
- * @param mthnameidx  constant_pool index in @b pcfs of method name to
- *                    locate in @b clsnameidx.
+ * @param mthnameidx  @c @b constant_pool index in @b pcfs of method
+ *                    name to locate in @b clsnameidx.
  *
- * @param mthdescidx  constant_pool index in @b pcfs of method
+ * @param mthdescidx  @c @b constant_pool index in @b pcfs of method
  *                    description with method name @b mthnameidx
  *                    to locate in @b clsnameidx.
  *
@@ -1227,6 +1249,8 @@
                                jvm_constant_pool_index mthdescidx,
                                rboolean            find_registerNatives)
 {
+    ARCH_FUNCTION_NAME(native_locate_local_mathod);
+
     rint nmoclsnameidx;
     rint nmomthnameidx;
 
@@ -1347,13 +1371,13 @@
  *
  * @param clsidx     Class table index of native method to invoke.
  *
- * @param mthnameidx Class file constant_pool index of name of native
- *                   method to invoke.  This entry must be a
+ * @param mthnameidx Class file @c @b constant_pool index of name of
+ *                   native method to invoke.  This entry must be a
  *                   CONSTANT_Utf8_info string containing an
  *                   unqualified method name.
  *
- * @param mthdescidx Class file constant_pool index of descriptor of
- *                   method to invoke.  This entry must be a
+ * @param mthdescidx Class file @c @b constant_pool index of descriptor
+ *                   of method to invoke.  This entry must be a
  *                   CONSTANT_Utf8_info string containing the
  *                   descriptor of an unqualified method name.
  *
@@ -1368,6 +1392,8 @@
                         jvm_constant_pool_index   mthnameidx,
                         jvm_constant_pool_index   mthdescidx)
 {
+    ARCH_FUNCTION_NAME(native_run_method);
+
     /*!
      * Verify that this local native method ordinal is both
      * unique and complete.
@@ -1381,8 +1407,9 @@
          */
         case JVMCFG_JLOBJECT_NMO_NULL:
             /*!
-             * @todo Invoke the full JNI interface for this method at
-             *       this place.  Additional parameters will be needed.
+             * @todo HARMONY-6-jvm-native.c-3 Invoke the full JNI
+             *       interface for this method at this place.
+             *       Additional parameters will be needed.
              *
              * Currently, the JNI interface is stubbed out here.
              * The implementation goes something like this:
@@ -1493,8 +1520,8 @@
 
                 default:
                 /*!
-                 * @todo  Which is the better error, @b VerifyError
-                 *        or @b NoSuchMethodError ?
+                 * @todo  HARMONY-6-jvm-native.c-4 Which is the better
+                 *       error, @b VerifyError or @b NoSuchMethodError ?
                  */
                 exit_throw_exception(EXIT_JVM_METHOD,
                                      JVMCLASS_JAVA_LANG_VERIFYERROR);

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/native.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/native.h?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/native.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/native.h Wed Oct 19 01:44:42 2005
@@ -12,7 +12,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -36,13 +38,16 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
  *
  */
 
-ARCH_COPYRIGHT_APACHE(native, h, "$URL$ $Id$");
+ARCH_HEADER_COPYRIGHT_APACHE(native, h,
+"$URL$",
+"$Id$");
 
 /* Prototypes for functions in 'native.c' */
 

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.h?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.h Wed Oct 19 01:44:42 2005
@@ -16,7 +16,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -40,13 +42,16 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
  *
  */
 
-ARCH_COPYRIGHT_APACHE(nts, h, "$URL$ $Id$");
+ARCH_HEADER_COPYRIGHT_APACHE(nts, h,
+"$URL$",
+"$Id$");
 
 /* Prototypes for functions in 'nts.c' */
 

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/object.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/object.h?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/object.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/object.h Wed Oct 19 01:44:42 2005
@@ -49,7 +49,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -73,13 +75,16 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
  *
  */
 
-ARCH_COPYRIGHT_APACHE(object, h, "$URL$ $Id$");
+ARCH_HEADER_COPYRIGHT_APACHE(object, h,
+"$URL$",
+"$Id$");
 
 
 /*
@@ -95,11 +100,12 @@
  * them using the @p @b objhash index.
  *
  * @param objhash  Object table index into the global
- * @link #rjvm.object rjvm.object[]@endlink array (via
- * @link #pjvm pjvm->object[]@endlink).
+ *                 @link #rjvm.object rjvm.object[]@endlink array (via
+ *                 @link #pjvm pjvm->object[]@endlink).
  * 
  * 
  * @returns pointer to a object slot
+ * 
  */
 #define OBJECT(objhash) pjvm->object[objhash]
 

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/objectutil.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/objectutil.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/objectutil.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/objectutil.c Wed Oct 19 01:44:42 2005
@@ -11,18 +11,21 @@
  *
  *
  * @internal Due to the fact that the implementation of the Java object
- * and the supporting robject structure is deeply embedded in the core
- * of the development of this software, this file has contents
- * that come and go during development.  Some functions get
- * staged here before deciding where they @e really go; some
- * are interim functions for debugging, some were glue that eventually
- * went away.  Be careful to remove prototypes to such functions
- * from the appropriate header file.
+ *           and the supporting robject structure is deeply embedded in
+ *           the core of the development of this software, this file
+ *           has contents that come and go during development.  Some
+ *           functions get staged here before deciding where they
+ *           @e really go; some are interim functions for debugging,
+ *           some were glue that eventually went away.  Be careful to
+ *           remove prototypes to such functions from the appropriate
+ *           header file.
  *
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -46,6 +49,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -53,7 +57,9 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(objectutil, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(objectutil, c,
+"$URL$",
+"$Id$");
 
 
 #include "jvmcfg.h"
@@ -82,10 +88,12 @@
  *          otherwise @link #rfalse rfalse@endlink.
  *
  *
- * @todo Make sure @b IllegalMonitorStateException logic covers all
+ * @todo HARMONY-6-jvm-objectutil.c-1 Make sure
+ *       @b IllegalMonitorStateException logic covers all
  *       possibilities or needs to be removed.
  *
- * @todo Make sure thread interruption logic below here is working.
+ * @todo HARMONY-6-jvm-objectutil.c-2 Make sure thread interruption
+ *       logic below here is working.
  *
  * @throws JVMCLASS_JAVA_LANG_NULLPOINTEREXCEPTION
  *         @link #JVMCLASS_JAVA_LANG_NULLPOINTEREXCEPTION
@@ -102,6 +110,8 @@
 rboolean objectutil_synchronize(jvm_object_hash  objhashthis,
                                 jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(objectutil_synchronize);
+
 #if 0
     /* If this thread cannot possibly own the object's monitor lock */
     if (some_condition)
@@ -203,7 +213,8 @@
  * @returns @link #rvoid rvoid@endlink
  *
  *
- * @todo Make sure thread interruption logic below here is working.
+ * @todo HARMONY-6-jvm-objectutil.c-3 Make sure thread interruption
+ *       logic below here is working.
  *
  *
  * @throws JVMCLASS_JAVA_LANG_ILLEGALMONITORSTATEEXCEPTION
@@ -214,11 +225,16 @@
 rvoid objectutil_unsynchronize(jvm_object_hash  objhashthis,
                                jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(objectutil_unsynchronize);
+
     /* Requested object must be in use and not null */
     if ((!(OBJECT_STATUS_INUSE & OBJECT(objhashthis).status))     ||
         (OBJECT_STATUS_NULL & OBJECT(objhashthis).status))
     {
-        /*! @todo Should the not INUSE condition cause INTERNALERROR? */
+        /*!
+         * @todo HARMONY-6-jvm-objectutil.c-4 Should the not INUSE
+         *       condition cause INTERNALERROR?
+         */
 
         thread_throw_exception(CURRENT_THREAD,
                                THREAD_STATUS_THREW_EXCEPTION,
@@ -265,12 +281,15 @@
  * @param  thridx       Thread table index of a thread requesting
  *                      to release this object's monitor lock.
  *
+ *
  * @returns the result of threadstate_request_release()
  *
  */
 rboolean objectutil_release(jvm_object_hash  objhashthis,
                            jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(objectutil_release);
+
     /* Preserve MLOCK object's hash for transition to next states */
     THREAD(thridx).locktarget = objhashthis;
 

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opcode.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opcode.h?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opcode.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opcode.h Wed Oct 19 01:44:42 2005
@@ -10,7 +10,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -34,13 +36,16 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
  *
  */
 
-ARCH_COPYRIGHT_APACHE(opcode, h, "$URL$ $Id$");
+ARCH_HEADER_COPYRIGHT_APACHE(opcode, h,
+"$URL$",
+"$Id$");
 
 
 /*!

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/stdio.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/stdio.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/stdio.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/stdio.c Wed Oct 19 01:44:42 2005
@@ -14,10 +14,16 @@
  * HAS IT COMPILED.  (You may get unexplainable @b SIGSEGV
  * errors otherwise.)
  *
+ * At the end of the initial development cycle, a suite of files
+ * called @b portable_*.c were developed to isolate @e all @b system(2)
+ * calls and @b library(3) functions to they are all compiled in a
+ * same way independent of the application code.
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -41,6 +47,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -48,7 +55,9 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(stdio, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(stdio, c,
+"$URL$",
+"$Id$");
 
 
 #include <stdio.h>
@@ -93,8 +102,10 @@
 
 /*@{ */ /* Begin grouped definitions */
 
-int sysDbgMsg(rint dml, rchar *fn, rchar *fmt, ...)
+int sysDbgMsg(rint dml, const rchar *fn, rchar *fmt, ...)
 {
+    ARCH_FUNCTION_NAME(sysDbgMsg);
+
     /* Display @e nothing if debug messages are disabled */
     if (rfalse == JVMCFG_DEBUG_MESSAGE_ENABLE)
     {
@@ -127,8 +138,10 @@
 } /* END of sysDbgMsg() */
 
 
-int sysErrMsg(rchar *fn, rchar *fmt, ...)
+int sysErrMsg(const rchar *fn, rchar *fmt, ...)
 {
+    ARCH_FUNCTION_NAME(sysErrMsg);
+
     rchar extfmt[JVMCFG_STDIO_BFR]; /* WARNING!  On the stack! */
 
     /* Load up format string w/ user specification */
@@ -150,6 +163,8 @@
 
 int sysErrMsgBfrFormat(rchar *bfr, rchar *fn, rchar *fmt, ...)
 {
+    ARCH_FUNCTION_NAME(sysErrMsgBfrFormat);
+
     rchar extfmt[JVMCFG_STDIO_BFR]; /* WARNING!  On the stack! */
 
     /* Load up format string w/ user specification */
@@ -225,6 +240,8 @@
 
 int fprintfLocalStdout(rchar *fmt, ...)
 {
+    ARCH_FUNCTION_NAME(fprintfLocalStdout);
+
     LOCAL_FPRINTF(stdout);
 
 } /* END of fprintfLocalStdout() */
@@ -232,12 +249,16 @@
 
 int fprintfLocalStderr(rchar *fmt, ...)
 {
+    ARCH_FUNCTION_NAME(fprintfLocalStderr);
+
     LOCAL_FPRINTF(stderr);
 
 } /* END of fprintfLocalStderr() */
 
 int sprintfLocal(rchar *bfr, rchar *fmt, ...)
 {
+    ARCH_FUNCTION_NAME(sprintfLocal);
+
     LOCAL_SPRINTF;
 
 } /* END of sprintfLocal() */
@@ -275,21 +296,27 @@
 
 int _printfLocal(const rchar *fmt, ...)
 {
-    return(sysErrMsg("_printfLocal",
+    ARCH_FUNCTION_NAME(_printfLocal);
+
+    return(sysErrMsg(arch_function_name,
                      "Please use 'printfLocal' function instead"));
 
 } /* END of _printfLocal() */
     
 int _fprintfLocal(FILE *fp,  const rchar *fmt, ...)
 {
-    return(sysErrMsg("_fprintfLocal",
+    ARCH_FUNCTION_NAME(_fprintfLocal);
+
+    return(sysErrMsg(arch_function_name,
                      "Please use 'fprintfLocal' function instead"));
 
 } /* END of _fprintfLocal() */
 
 int _sprintfLocal(rchar *bfr, const rchar *fmt, ...)
 {
-    return(sysErrMsg("_sprintfLocal",
+    ARCH_FUNCTION_NAME(_sprintfLocal);
+
+    return(sysErrMsg(arch_function_name,
                      "Please use 'sprintfLocal' function instead"));
 
 } /* END of _sprintfLocal() */

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/threadstate.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/threadstate.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/threadstate.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/threadstate.c Wed Oct 19 01:44:42 2005
@@ -286,7 +286,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -310,6 +312,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -317,7 +320,9 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(threadstate, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(threadstate, c,
+"$URL$",
+"$Id$");
 
 
 #include "jvmcfg.h"
@@ -427,6 +432,7 @@
  *                          explicitly stated if this state change is
  *                          unconditional.
  *
+ *
  * @returns @link #rtrue rtrue@endlink if state change was permitted,
  *          otherwise @link #rfalse rfalse@endlink.
  *
@@ -527,10 +533,10 @@
  * See tables above for full description.
  *
  * 
- * @todo  Need to find a way (per spec section 5.3.5) to throw
- *        a java.lang.LinkageError and/or java.lang.ClassFormatError
- *        for bad classfile representations.  Also major/minor versions
- *        mismatch should throw
+ * @todo  HARMONY-6-jvm-threadstate.c-1 Need to find a way (per spec
+ *        section 5.3.5) to throw a java.lang.LinkageError and/or
+ *        java.lang.ClassFormatError for bad classfile representations.
+ *        Also major/minor versions mismatch should throw
  *        java/class/UnsupportedClassVersion error.
  *
  *
@@ -538,7 +544,7 @@
  *
  *
  * @returns @link #rtrue rtrue@endlink if all activities were
- * successful, else @link #rfalse rfalse@endlink.
+ *          successful, else @link #rfalse rfalse@endlink.
  *
  */
 
@@ -555,6 +561,8 @@
  */
 rboolean threadstate_request_new(jvm_thread_index thridx)
 {
+            ARCH_FUNCTION_NAME(threadstate_request_new);
+
     STATE_REQUEST(NEW, (rtrue));
     STATE_END(rtrue);
 }
@@ -566,6 +574,8 @@
  */
 rboolean threadstate_activate_new(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_new);
+
     STATE_ACTIVATE(NEW);
     STATE_END(rtrue);
 }
@@ -579,6 +589,8 @@
  */
 rboolean threadstate_process_new(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_new);
+
     STATE_PROCESS(NEW);
     STATE_END(rtrue);
 }
@@ -594,6 +606,8 @@
 
 rboolean threadstate_request_start(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_start);
+
     STATE_REQUEST(START, (THREAD_STATE_NEW == THIS_STATE(thridx)));
     STATE_END(rtrue);
 }
@@ -605,6 +619,8 @@
  */
 rboolean threadstate_activate_start(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_start);
+
     STATE_ACTIVATE(START);
     STATE_END(rtrue);
 }
@@ -618,6 +634,8 @@
  */
 rboolean threadstate_process_start(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_start);
+
     STATE_PROCESS(START);
 
     /* ... Process activities for this thread state here ... */
@@ -636,6 +654,8 @@
  */
 rboolean threadstate_request_runnable(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_runnable);
+
     STATE_REQUEST(RUNNABLE, 
                   ((THREAD_STATE_START     == THIS_STATE(thridx)) ||
                    (THREAD_STATE_RUNNING   == THIS_STATE(thridx)) ||
@@ -651,6 +671,8 @@
  */
 rboolean threadstate_activate_runnable(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_runnable);
+
     STATE_ACTIVATE(RUNNABLE);
     STATE_END(rtrue);
 }
@@ -666,6 +688,8 @@
  */
 rboolean threadstate_process_runnable(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_runnable);
+
     STATE_PROCESS(RUNNABLE);
     STATE_END(rtrue);
 }
@@ -686,6 +710,8 @@
  */
 rboolean threadstate_request_running(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_running);
+
     STATE_REQUEST(RUNNING,
                   (THREAD_STATE_RUNNABLE == THIS_STATE(thridx)));
     STATE_END(rtrue);
@@ -698,6 +724,8 @@
  */
 rboolean threadstate_activate_running(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_running);
+
     STATE_ACTIVATE(RUNNING);
     STATE_END(rtrue);
 }
@@ -715,6 +743,8 @@
  */
 rboolean threadstate_process_running(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_running);
+
     STATE_PROCESS(RUNNING);
 
    STATE_END(opcode_run(CURRENT_THREAD, rtrue));
@@ -739,6 +769,8 @@
  */
 rboolean threadstate_request_complete(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_complete);
+
     STATE_REQUEST(COMPLETE,
                   ((THREAD_STATE_NEW      == THIS_STATE(thridx)) ||
                    (THREAD_STATE_RUNNING  == THIS_STATE(thridx)) ||
@@ -754,6 +786,8 @@
  */
 rboolean threadstate_activate_complete(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_complete);
+
     STATE_ACTIVATE(COMPLETE);
     STATE_END(rtrue);
 }
@@ -767,6 +801,8 @@
  */
 rboolean threadstate_process_complete(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_complete);
+
     STATE_PROCESS(COMPLETE);
     STATE_END(threadstate_request_dead(thridx));
 }
@@ -787,6 +823,8 @@
  */
 rboolean threadstate_request_blockingevent(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_blockingevent);
+
     STATE_REQUEST(BLOCKINGEVENT,
                   ((THREAD_STATE_RUNNING  == THIS_STATE(thridx)) ||
                    (THREAD_STATE_BADLOGIC == THIS_STATE(thridx))));
@@ -800,6 +838,8 @@
  */
 rboolean threadstate_activate_blockingevent(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_blockingevent);
+
     STATE_ACTIVATE(BLOCKINGEVENT);
     STATE_END(rtrue);
 }
@@ -813,6 +853,8 @@
  */
 rboolean threadstate_process_blockingevent(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_blockingevent);
+
     STATE_PROCESS(BLOCKINGEVENT);
 
     STATE_END(threadstate_request_blocked(thridx));
@@ -828,6 +870,8 @@
  */
 rboolean threadstate_request_blocked(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_blocked);
+
     STATE_REQUEST(BLOCKED,
                   (THREAD_STATE_BLOCKINGEVENT == THIS_STATE(thridx)));
     STATE_END(rtrue);
@@ -840,6 +884,8 @@
  */
 rboolean threadstate_activate_blocked(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_blocked);
+
     STATE_ACTIVATE(BLOCKED);
     STATE_END(rtrue);
 }
@@ -853,6 +899,8 @@
  */
 rboolean threadstate_process_blocked(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_blocked);
+
     STATE_PROCESS(BLOCKED);
     STATE_END(rtrue);
 }
@@ -868,6 +916,8 @@
  */
 rboolean threadstate_request_unblocked(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_unblocked);
+
     STATE_REQUEST(UNBLOCKED,
                   (THREAD_STATE_UNBLOCKED == THIS_STATE(thridx)));
     STATE_END(rtrue);
@@ -880,6 +930,8 @@
  */
 rboolean threadstate_activate_unblocked(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_unblocked);
+
     STATE_ACTIVATE(UNBLOCKED);
     STATE_END(rtrue);
 }
@@ -893,6 +945,8 @@
  */
 rboolean threadstate_process_unblocked(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_unblocked);
+
     STATE_PROCESS(UNBLOCKED);
 
     STATE_END(threadstate_request_runnable(thridx));
@@ -909,6 +963,8 @@
  */
 rboolean threadstate_request_synchronized(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_synchronized);
+
     STATE_REQUEST(SYNCHRONIZED,
                   (THREAD_STATE_RUNNING == THIS_STATE(thridx)));
     STATE_END(rtrue);
@@ -921,6 +977,8 @@
  */
 rboolean threadstate_activate_synchronized(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_synchronized);
+
     STATE_ACTIVATE(SYNCHRONIZED);
     STATE_END(rtrue);
 }
@@ -934,6 +992,8 @@
  */
 rboolean threadstate_process_synchronized(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_synchronized);
+
     STATE_PROCESS(SYNCHRONIZED);
 
     STATE_END(threadstate_request_lock(thridx));
@@ -950,6 +1010,8 @@
  */
 rboolean threadstate_request_release(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_release);
+
     STATE_REQUEST(RELEASE,
                   (THREAD_STATE_RUNNING == THIS_STATE(thridx)));
     STATE_END(rtrue);
@@ -962,6 +1024,8 @@
  */
 rboolean threadstate_activate_release(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_release);
+
     STATE_ACTIVATE(RELEASE);
 
     STATE_END(rtrue);
@@ -979,6 +1043,8 @@
  */
 rboolean threadstate_process_release(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_release);
+
     STATE_PROCESS(RELEASE);
 
     jvm_object_hash locktarget = THREAD(thridx).locktarget;
@@ -1019,6 +1085,8 @@
  */
 rboolean threadstate_request_wait(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_wait);
+
     STATE_REQUEST(WAIT, (THREAD_STATE_RELEASE == THIS_STATE(thridx)));
 
     STATE_END(rtrue);
@@ -1031,6 +1099,8 @@
  */
 rboolean threadstate_activate_wait(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_wait);
+
     STATE_ACTIVATE(WAIT);
 
     STATE_END(rtrue);
@@ -1045,6 +1115,8 @@
  */
 rboolean threadstate_process_wait(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_wait);
+
     STATE_PROCESS(WAIT);
 
     STATE_END(rtrue);
@@ -1061,6 +1133,8 @@
  */
 rboolean threadstate_request_notify(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_notify);
+
     STATE_REQUEST(NOTIFY, (THREAD_STATE_WAIT == THIS_STATE(thridx)));
 
     STATE_END(rtrue);
@@ -1073,6 +1147,8 @@
  */
 rboolean threadstate_activate_notify(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_notify);
+
     STATE_ACTIVATE(NOTIFY);
 
     STATE_END(rtrue);
@@ -1087,6 +1163,8 @@
  */
 rboolean threadstate_process_notify(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_notify);
+
     STATE_PROCESS(NOTIFY);
 
     STATE_END(threadstate_request_lock(thridx));
@@ -1103,6 +1181,8 @@
  */
 rboolean threadstate_request_lock(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_lock);
+
     STATE_REQUEST(LOCK,
                   ((THREAD_STATE_SYNCHRONIZED == THIS_STATE(thridx)) ||
                    (THREAD_STATE_NOTIFY       == THIS_STATE(thridx))));
@@ -1116,6 +1196,8 @@
  */
 rboolean threadstate_activate_lock(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_lock);
+
     STATE_ACTIVATE(LOCK);
 
     STATE_END(rtrue);
@@ -1136,6 +1218,8 @@
  */
 rboolean threadstate_process_lock(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_lock);
+
     STATE_PROCESS(LOCK);
 
     /*
@@ -1173,6 +1257,8 @@
  */
 rboolean threadstate_request_acquire(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_acquire);
+
     STATE_REQUEST(ACQUIRE, (THREAD_STATE_LOCK == THIS_STATE(thridx)));
 
     STATE_END(rtrue);
@@ -1185,6 +1271,8 @@
  */
 rboolean threadstate_activate_acquire(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_acquire);
+
     STATE_ACTIVATE(ACQUIRE);
 
     STATE_END(rtrue);
@@ -1199,6 +1287,8 @@
  */
 rboolean threadstate_process_acquire(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_acquire);
+
     STATE_PROCESS(ACQUIRE);
 
     STATE_END(threadstate_request_runnable(thridx));
@@ -1215,6 +1305,8 @@
  */
 rboolean threadstate_request_dead(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_dead);
+
     STATE_REQUEST(DEAD, (THREAD_STATE_COMPLETE == THIS_STATE(thridx)));
 
     STATE_END(rtrue);
@@ -1227,6 +1319,8 @@
  */
 rboolean threadstate_activate_dead(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_dead);
+
     STATE_ACTIVATE(DEAD);
 
     STATE_END(rtrue);
@@ -1250,6 +1344,8 @@
  */
 rboolean threadstate_process_dead(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_dead);
+
     STATE_PROCESS(DEAD);
 
     STATE_END(thread_die(thridx));
@@ -1270,6 +1366,8 @@
  */
 rboolean threadstate_request_badlogic(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_request_badlogic);
+
     STATE_REQUEST(BADLOGIC, (rtrue));
 
     STATE_END(rtrue);
@@ -1282,6 +1380,8 @@
  */
 rboolean threadstate_activate_badlogic(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_activate_badlogic);
+
     STATE_ACTIVATE(BADLOGIC);
 
     STATE_END(rtrue);
@@ -1300,6 +1400,8 @@
  */
 rboolean threadstate_process_badlogic(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(threadstate_process_badlogic);
+
     STATE_PROCESS(BADLOGIC);
 
     STATE_END(rtrue);

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/timeslice.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/timeslice.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/timeslice.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/timeslice.c Wed Oct 19 01:44:42 2005
@@ -3,6 +3,12 @@
  *
  * @brief JVM one millisecond time slice timer.
  *
+ * @attention This file contains data structures and functionality
+ *            found nowhere else in the project.  It is inherently
+ *            platform-specific and porting to different platforms
+ *            must be done carefully so that nothing breaks on the
+ *            existing implementations.
+ *
  * The @link rjvm.timeslice_expired pjvm->timeslice_expired@endlink
  * flag is set by the periodic @b SIGALRM herein and tested in the JVM
  * virtual instruction inner loop to decide when a thread has finished
@@ -23,7 +29,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -47,6 +55,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -54,19 +63,25 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(timeslice, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(timeslice, c,
+"$URL$",
+"$Id$");
 
 
 #include <unistd.h>
 #include <signal.h>
+#if defined(CONFIG_WINDOWS) || defined(CONFIG_CYGWIN)
 #include <sys/time.h>
+#endif 
 
 #define _REENTRANT
 #include <pthread.h>
 
 #ifndef CONFIG_WINDOWS
+#ifndef CONFIG_CYGWIN
 #include <thread.h> /* WATCH OUT!  /usr/include, not application .h */
 #endif
+#endif
 
 #include "jvmcfg.h"
 #include "classfile.h"
@@ -88,11 +103,13 @@
  * @b Parameters: @link #rvoid rvoid@endlink
  *
  *
- *       @returns @link #rvoid rvoid@endlink
+ * @returns @link #rvoid rvoid@endlink
  *
  */
 rvoid timeslice_init()
 {
+    ARCH_FUNCTION_NAME(timeslice_init);
+
     /* Time slice has not expired */
     pjvm->timeslice_expired = rfalse;
 
@@ -109,7 +126,7 @@
 
     if (0 != rc)
     {
-        sysErrMsg("timeslice_init", "Cannot start timer");
+        sysErrMsg(arch_function_name, "Cannot start timer");
         exit_jvm(EXIT_TIMESLICE_START);
 /*NOTREACHED*/
     }
@@ -128,8 +145,7 @@
  *
  *
  * @param  thridx   Thread index of thread to read its 
- *                  @link rthread#sleeptime sleeptime@endlink
- *                  value
+ *                  @link rthread#sleeptime sleeptime@endlink value
  *
  *
  * @returns remaining sleep time, in timer ticks
@@ -137,6 +153,8 @@
  */
 jlong timeslice_get_thread_sleeptime(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(timeslice_get_thread_sleeptime);
+
     jlong rc;
 
     /* Lock out the @e world while retrieving any thread's sleep time */
@@ -167,7 +185,7 @@
  * @b Parameters: @link #rvoid rvoid@endlink
  *
  *
- *       @returns @link #rvoid rvoid@endlink
+ * @returns @link #rvoid rvoid@endlink
  *
  *
  * @warning Eclipse users need to remember that setting a combination
@@ -191,6 +209,8 @@
 
 static void timeslice_tick(/* void --GCC won't allow this declaration*/)
 {
+    ARCH_FUNCTION_NAME(timeslice_tick);
+
     /* Suppress SIGALRM until finished with this handler */
     signal(SIGALRM, SIG_IGN);
 
@@ -200,7 +220,7 @@
         if (JVMCFG_TIMESLICE_DEBUG_REPORT_MIN_SECONDS <=
             timeslice_period.it_interval.tv_sec)
         {
-            sysDbgMsg(DML9, "timeslice_tick", "tick");
+            sysDbgMsg(DML9, arch_function_name, "tick");
         }
     }
 
@@ -234,6 +254,8 @@
  */
 void *timeslice_run(void *dummy)
 {
+    ARCH_FUNCTION_NAME(timeslice_run);
+
     /* Start timer and make its first tick one period from now */
     timeslice_period.it_interval.tv_sec =
                                         JVMCFG_TIMESLICE_PERIOD_SECONDS;
@@ -260,7 +282,7 @@
 
         if (0 != rc)
         {
-            sysErrMsg("timeslice_run", "Cannot start interval timer");
+            sysErrMsg(arch_function_name,"Cannot start interval timer");
             exit_jvm(EXIT_TIMESLICE_START);
 /*NOTREACHED*/
         }
@@ -278,15 +300,16 @@
 
     while(rtrue)
     {
-    	/*
-    	 *  gmj : I think that yield() is solaris only
-    	 */
-
-        #ifdef CONFIG_WINDOWS    
-        	/* do something useful */
-        #else		 
-	        yield();
-	    #endif
+        /*!
+         * @todo HARMONY-6-jvm-timeslice.c-1 gmj : I think that
+         *       yield( is solaris only
+         *
+         */
+#if defined(CONFIG_WINDOWS) || defined(CONFIG_CYGWIN)
+        /* do something useful */
+#else
+        yield();
+#endif
     }
 
 /*NOTREACHED*/
@@ -302,18 +325,23 @@
  * @b Parameters: @link #rvoid rvoid@endlink
  *
  *
- *       @returns @link #rvoid rvoid@endlink
+ * @returns @link #rvoid rvoid@endlink
  *
  */
 rvoid timeslice_shutdown(rvoid)
 {
+    ARCH_FUNCTION_NAME(timeslice_shutdown);
+
     /* Suppress SIGALRM so future tick does not happen AT ALL */
     signal(SIGALRM, SIG_IGN);
 
     /* Ignore error */
     pthread_cancel(posix_thread_id);
 
-    /*! @todo Is this necessary at JVM shutdown time? */
+    /*!
+     * @todo HARMONY-6-jvm-timeslice.c-2 Is this necessary at
+     *       JVM shutdown time?
+     */
     /* pthread_mutex_destroy(&pjvm->sleeplock); */
 
     /* Declare this module uninitialized */

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.c Wed Oct 19 01:44:42 2005
@@ -20,7 +20,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -44,6 +46,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -51,7 +54,9 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(unicode, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(unicode, c,
+"$URL$",
+"$Id$");
 
 
 #include <string.h>
@@ -73,10 +78,10 @@
  * @param[out] outbfr  UTF8 byte string
  *
  *
- * @returns  UTF8 structure containing length and character buffer (plus
- *           tag), but return in (cp_info_dup) for full proper word
- *           alignment. When done with the data, call HEAP_FREE_DATA()
- *           on it.
+ * @returns UTF8 structure containing length and character buffer (plus
+ *          tag), but return in (cp_info_dup) for full proper word
+ *          alignment. When done with the data, call HEAP_FREE_DATA()
+ *          on it.
  *
  *    @c @b rc-\>bytes    UTF8 version of @b inbfr string in @b outbfr
  *
@@ -90,6 +95,8 @@
 
 cp_info_dup *unicode_cnv2utf(jchar *inbfr, jshort length)
 {
+    ARCH_FUNCTION_NAME(unicode_cnv2utf);
+
     jshort bytecnvcount = 0;
     jshort unicodecnvcount;
     jubyte *outbfr;
@@ -253,6 +260,8 @@
  */
 jshort unicode_strcmp(jchar *s1, u2 l1, jchar *s2, u2 l2)
 {
+    ARCH_FUNCTION_NAME(unicode_strcmp);
+
     /* Compare shortest common run length */
     rint cmplen = (l1 < l2) ? l1 : l2;
 

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.h?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.h Wed Oct 19 01:44:42 2005
@@ -16,7 +16,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -40,13 +42,16 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
  *
  */
 
-ARCH_COPYRIGHT_APACHE(unicode, h, "$URL$ $Id$");
+ARCH_HEADER_COPYRIGHT_APACHE(unicode, h,
+"$URL$",
+"$Id$");
 
 
 /* Prototypes for functions in 'unicode.c' */

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.h?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.h Wed Oct 19 01:44:42 2005
@@ -15,7 +15,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -39,6 +41,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -48,7 +51,9 @@
 
 /* Prototypes for functions in 'utf.c' */
 
-ARCH_COPYRIGHT_APACHE(utf, h, "$URL$ $Id$");
+ARCH_HEADER_COPYRIGHT_APACHE(utf, h,
+"$URL$",
+"$Id$");
 
 extern jshort utf_utf2unicode(CONSTANT_Utf8_info *utf_inbfr,
                               jchar              *outbfr);
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmutil.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/jvmutil.c Wed Oct 19 01:44:42 2005
@@ -7,7 +7,9 @@
  *
  * @section Control
  *
- * \$URL$ \$Id$
+ * \$URL$
+ *
+ * \$Id$
  *
  * Copyright 2005 The Apache Software Foundation
  * or its licensors, as applicable.
@@ -31,6 +33,7 @@
  * @date \$LastChangedDate$
  *
  * @author \$LastChangedBy$
+ *
  *         Original code contributed by Daniel Lydick on 09/28/2005.
  *
  * @section Reference
@@ -38,7 +41,9 @@
  */
 
 #include "arch.h"
-ARCH_COPYRIGHT_APACHE(jvmutil, c, "$URL$ $Id$");
+ARCH_SOURCE_COPYRIGHT_APACHE(jvmutil, c,
+"$URL$",
+"$Id$");
 
 
 #include "jvmcfg.h" 
@@ -89,12 +94,15 @@
  *
  * @param  level     New level to set.
  *
+ *
  * @returns @link #rvoid rvoid@endlink
  *
  */
 
 rvoid jvmutil_set_dml(jvm_debug_level_enum level)
 {
+    ARCH_FUNCTION_NAME(jvmutil_set_dml);
+
     pjvm->debug_message_level = level;
 
 } /* END of jvmutil_set_dml() */
@@ -107,11 +115,13 @@
  * @b Parameters: @link #rvoid rvoid@endlink
  *
  *
- *       @returns current debug message verbosity
+ * @returns current debug message verbosity
  *
  */
 jvm_debug_level_enum jvmutil_get_dml()
 {
+    ARCH_FUNCTION_NAME(jvmutil_get_dml);
+
     return(pjvm->debug_message_level);
 
 } /* END of jvmutil_get_dml() */
@@ -129,8 +139,8 @@
  * in the stack frame.
  *
  * @attention These routines are @e not intended as a replacement
- * for the normal routine
- * <b><code>java.lang.Throwable.printStackTrace()</code></b> !!!
+ *            for the normal routine
+ *         <b><code>java.lang.Throwable.printStackTrace()</code></b> !!!
  *
  * @param  thridx      Thread table index of thread to show
  *
@@ -149,10 +159,10 @@
  * @returns @link #rvoid rvoid@endlink
  *
  *
  * @todo  This function needs unit testing.
  *
  * @todo  Add line numbers to output.  Sample output might look like
  *        this (when line numbers are added):
  *
  * @verbatim
  * Exception in thread "main" java.lang.NullPointerException
@@ -174,6 +184,8 @@
                                         rboolean          showdetails,
                                         rboolean          showlocals)
 {
+    ARCH_FUNCTION_NAME(jvmutil_print_stack_common);
+
     /* Print header if one is passed in, else skip */
     if (rnull != pheader)
     {
@@ -254,18 +266,21 @@
 
                  star_len_src, star_len_src,
                  srcname,
-                 0 /*! @todo  Get line numbers */);
+                 0 /*! @todo  HARMONY-6-jvm-jvmutil.c-3 Get line
+                              numbers */);
 
         /*
          * Fill in frame details and local variables
          */
         if (rtrue == showdetails)
         {
-            /*! @todo Show details of stack frame */
+            /*! @todo HARMONY-6-jvm-jvmutil.c-4 Show details
+                      of stack frame */
 
             if (rtrue == showlocals)
             {
-                /*! @todo Show local variables in stack frame */
+                /*! @todo HARMONY-6-jvm-jvmutil.c-5 Show local
+                          variables in stack frame */
             }
         }
 
@@ -282,6 +297,8 @@
  */
 rvoid jvmutil_print_stack(jvm_thread_index thridx, rchar *pheader)
 {
+    ARCH_FUNCTION_NAME(jvmutil_print_stack);
+
     jvmutil_print_stack_common(thridx, pheader, rfalse, rfalse);
 
 } /* END of jvmutil_print_stack() */
@@ -294,6 +311,8 @@
 rvoid jvmutil_print_stack_details(jvm_thread_index  thridx,
                                   rchar            *pheader)
 {
+    ARCH_FUNCTION_NAME(jvmutil_print_stack_details);
+
     jvmutil_print_stack_common(thridx, pheader, rtrue, rfalse);
 
 } /* END of jvmutil_print_stack_details() */
@@ -306,6 +325,8 @@
 rvoid jvmutil_print_stack_locals(jvm_thread_index  thridx,
                                  rchar            *pheader)
 {
+    ARCH_FUNCTION_NAME(jvmutil_print_stack_locals);
+
     jvmutil_print_stack_common(thridx, pheader, rtrue, rtrue);
 
 } /* END of jvmutil_print_stack_locals() */
@@ -318,6 +339,8 @@
 static rvoid jvmutil_print_errtype_stack(jvm_thread_index  thridx,
                                          rchar            *errtype)
 {
+    ARCH_FUNCTION_NAME(jvmutil_print_errtype_stack);
+
     rchar *pheader = HEAP_GET_DATA(JVMCFG_STDIO_BFR, rfalse);
 
     jvm_class_index clsidx =
@@ -356,6 +379,8 @@
  */
 rvoid jvmutil_print_error_stack(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(jvmutil_print_error_stack);
+
     jvmutil_print_errtype_stack(thridx, "Error");
 
 } /* END of jvmutil_print_error_stack() */
@@ -368,6 +393,8 @@
  */
 rvoid jvmutil_print_exception_stack(jvm_thread_index thridx)
 {
+    ARCH_FUNCTION_NAME(jvmutil_print_exception_stack);
+
     jvmutil_print_errtype_stack(thridx, "Exception");
 
 } /* END of jvmutil_print_exception_stack() */
@@ -149,10 +159,10 @@
  *
  *
- * @todo  This function needs unit testing.
+ * @todo  HARMONY-6-jvm-jvmutil.c-1 This function needs unit testing.
  *
@@ -149,10 +159,10 @@
  *
- * @todo  Add line numbers to output.  Sample output might look like
- *        this (when line numbers are added):
+ * @todo  HARMONY-6-jvm-jvmutil.c-2 Add line numbers to output.  Sample
+ *        output might look like this (when line numbers are added):
  *
  * @verbatim

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/linkage.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/linkage.c?rev=326482&r1=326481&r2=326482&view=diff
==============================================================================